"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLogger = void 0;
const winston = require("winston");
const format = winston.format((info, opts) => {
    if (!info.metadata) {
        info.metadata = {};
    }
    const store = opts.storage.getStore();
    if (store) {
        const metadata = store.get('metadata') || {};
        info.metadata = Object.assign(Object.assign({}, info.metadata), metadata);
    }
    return info;
});
const getLogger = (options) => {
    return winston.createLogger({
        exitOnError: false,
        format: winston.format.combine(winston.format.errors({ stack: true }), winston.format.timestamp(), format({
            storage: options.storage
        }), winston.format.json()),
        defaultMeta: { app: options.app, hostname: process.env.HOSTNAME, environment: process.env.NODE_ENV },
        transports: [new winston.transports.Console()],
        exceptionHandlers: [
            new winston.transports.Console({ level: 'error' }),
        ],
        rejectionHandlers: [
            new winston.transports.Console({
                level: 'error',
            })
        ],
    });
};
exports.getLogger = getLogger;
//# sourceMappingURL=logger.js.map